==> server-api-impl-10.2.0-702.113-sources.jar: com/xebialabs/deployit/core/rest/json/DeploymentTaskReportLineWriter.scala <==
package com.xebialabs.deployit.core.rest.json

import com.xebialabs.deployit.core.rest.json.TaskWriterUtil.writeTaskWithBlock
import com.xebialabs.deployit.engine.api.dto.DeploymentTaskReportLine
import com.xebialabs.xltype.serialization.util.DateUtil
import org.springframework.stereotype.Component

import java.io.OutputStream
import java.lang.annotation.Annotation
import java.lang.reflect.Type
import javax.ws.rs.Produces
import javax.ws.rs.core.{MediaType, MultivaluedMap}
import javax.ws.rs.ext.{MessageBodyWriter, Provider}

@Component
@Provider
@Produces(Array(MediaType.APPLICATION_JSON))
class DeploymentTaskReportLineWriter extends MessageBodyWriter[DeploymentTaskReportLine] {
  override def isWriteable(`type`: Class[_],
                           genericType: Type,
                           annotations: Array[Annotation],
                           mediaType: MediaType): Boolean = classOf[DeploymentTaskReportLine].isAssignableFrom(`type`)

  override def writeTo(line: DeploymentTaskReportLine,
                       `type`: Class[_],
                       genericType: Type,
                       annotations: Array[Annotation],
                       mediaType: MediaType,
                       httpHeaders: MultivaluedMap[String, AnyRef],
                       entityStream: OutputStream): Unit = {
    writeTaskWithBlock(
      entityStream,
      List(
        "taskId" -> line.getTaskId,
        "startDate" -> DateUtil.toString(line.getStartDate),
        "completionDate" -> DateUtil.toString(line.getCompletionDate),
        "status" -> line.getStatus,
        "type" -> line.getTaskType,
        "user" -> line.getUser,
        "environment" -> line.getEnvironment,
        "environmentId" -> line.getEnvironmentId,
        "environmentIdWithoutRoot" -> line.getEnvironmentIdWithoutRoot,
        "package" -> line.getDeploymentPackage,
        "rolledBack" -> line.getRolledBack,
        "worker_name" -> line.getWorkerName
      ),
      Option(line.getBlock)
    )
  }
}

==> server-api-impl-24.3.14-1228.130-sources.jar: com/xebialabs/deployit/core/rest/json/DeploymentTaskReportLineWriter.scala <==
package com.xebialabs.deployit.core.rest.json

import com.xebialabs.deployit.core.rest.json.TaskWriterUtil.writeTaskWithBlock
import com.xebialabs.deployit.engine.api.dto.DeploymentTaskReportLine
import com.xebialabs.xltype.serialization.util.DateUtil
import org.springframework.stereotype.Component

import java.io.OutputStream
import java.lang.annotation.Annotation
import java.lang.reflect.Type
import jakarta.ws.rs.Produces
import jakarta.ws.rs.core.{MediaType, MultivaluedMap}
import jakarta.ws.rs.ext.{MessageBodyWriter, Provider}

@Component
@Provider
@Produces(Array(MediaType.APPLICATION_JSON))
class DeploymentTaskReportLineWriter extends MessageBodyWriter[DeploymentTaskReportLine] {
  override def isWriteable(`type`: Class[_],
                           genericType: Type,
                           annotations: Array[Annotation],
                           mediaType: MediaType): Boolean = classOf[DeploymentTaskReportLine].isAssignableFrom(`type`)

  override def writeTo(line: DeploymentTaskReportLine,
                       `type`: Class[_],
                       genericType: Type,
                       annotations: Array[Annotation],
                       mediaType: MediaType,
                       httpHeaders: MultivaluedMap[String, AnyRef],
                       entityStream: OutputStream): Unit = {
    writeTaskWithBlock(
      entityStream,
      List(
        "taskId" -> line.getTaskId,
        "startDate" -> DateUtil.toString(line.getStartDate),
        "completionDate" -> DateUtil.toString(line.getCompletionDate),
        "status" -> line.getStatus,
        "type" -> line.getTaskType,
        "user" -> line.getUser,
        "environment" -> line.getEnvironment,
        "environmentId" -> line.getEnvironmentId,
        "environmentIdWithoutRoot" -> line.getEnvironmentIdWithoutRoot,
        "package" -> line.getDeploymentPackage,
        "rolledBack" -> line.getRolledBack,
        "worker_name" -> line.getWorkerName
      ),
      Option(line.getBlock)
    )
  }
}
